==> Bundle-Search-0.01.tar.gz: Bundle-Search-0.01/lib/Bundle/Search.pm <==
package Bundle::Search;

use strict;
use warnings;

our $VERSION = '0.01';



1;
__END__


=head1 NAME

Bundle::Search - installs Search modules, related modules, and
                 dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Search'
  
=head1 CONTENTS

IPC::Shareable

Digest::SHA1

SHA

Digest::base

File::Find::Object

Heap

Term::ReadKey

Date::Format

Time::Zone 

Clone

Sub::Uplevel

Test::Simple

Test::Harness

IO::Stringy

DBI::PurePerl

App::Info

Time::Local

File::Which

File::Temp

File::Copy

Data::Dumper

File::chdir 

ExtUtils::CBuilder

Module::Build

Test

Scalar::Util

File::Basename::Object

Cache

Cache::Cache

Error

IPC::ShareLite

File::Cache

FreezeThaw

Cache::File

Tie::Hash

DB_File

File::NFSLock

Storable

Test::Exception

DBI

DBD::Pg

Archive::Zip

Bundle::Compress::Zlib

IO

IO::Zlib

IO::Select::Trap

Carp

XSLoader

Log::Agent

IO::File::Lockable

IO::File::Log

IO::File::CompressOnClose

IO::Tokenized

IO::BLOB::Pg

IO::File::Multi

IO::File::String

IO::File::Cached

DBD::AnyData

DBD::CSV

DBD::DBM

DBD::File

DBD::Gofer

DBD::mysql

DBD::NullP

DBD::Proxy

DBD::Sponge

SQL::Statement 

DBD::Template

DBD::TemplateSS

DBD::WMI

DBD::Excel

Bundle::Mysql

Bundle::SQL

AutoLoader

Pod::Simple

Test::Builder

Test::Builder::Tester

File::Spec

Pod::Coverage

Test::Pod 

Test::Pod::Coverage

Search::Glimpse

LWP

URI

HTML::Tagset

HTML::Parser

Search::Circa::Parser

String::Tokenizer

String::Tokeniser

Parse::Tokens

Text::Tokenizer

Search::QueryParser

Getopt::Long

Pragmatic

Time::Piece

Snowball::Norweigen

Snowball::Swedish

Bundle::Encode

Bundle::Unicode

Carp::Assert

Class::ISA

Class::Data::Inheritable

Class::Contract 

Class::Class

Class::Generate

Class::MethodMaker

Carp::Clan

Text::German

Lingua::Stem

Lingua::Stem::Snowball::DA

Lingua::Stem::Fr

Lingua::Stem::It

Lingua::Stem::RU

Lingua::PT::Stemmer

Tie::Array::Sorted

Memoize

List::Util

Class::Virtual

Class::Accessor

Class::Accessor::Fast

Bit::Vector

Bit::Vector::Minimal

Lucene

AnnoCPAN::Perldoc

AnnoCPAN::SyncDB

Params::Util

CSS::Tiny

Hook::LexWrap

Config::Tiny

Class::Inspector

File::Remove

Test::SubCalls

Test::ClassAPI

Test::Object

PPI 

PPI::HTML

Uri::QueryParam

Time::HiRes

Pod::POM

Pod::POM::View::HTML

Module::CoreList

List::MoreUtils

HTTP::Daemon

Encode::Guess

Config

Alien::GvaScript

Pod::POM::Web

Plucene

Search::FreeText

BerkeleyDB

Search::Indexer

Search::Estraier

Search::Equidistance

Search::Odeum

Class::ParmList

Class::NamedParms

Tie::FileLRUCache

Tie::DB_File::SplitHash

Search::InvertedIndex

Search::InvertedIndex::DB::Pg

Text::Aspell

Search::Tools

Search::Namazu

Text::Unidecode

Search::ContextGraph

Path::Class

List::Uniq

Class::Accessor::Chained

Set::Scalar

CDB_File

Text::Soundex

MealMaster

Search::Mousse

Search::VectorSpace

PerlBench::Stats

Net::Z3950

Net::Z3950::ZOOM

MARC

MARC::Record

YAML

Search::Z3950

Search::Lemur

Search::Binary

Want

Set::Array

Search::InvertedIndex::Simple

Search::InvertedIndex::Simple::BerkeleyDB

Search::FreeText

Date::Manip

CGI

HTML::Tree

HTML::TreeBuilder

IO::Capture::ErrorMessages

Pod::Usage

URI::Escape::XS

User

Test::File

Test::Pod

Email::Address

Email::Simple

Return::Value

Email::Send

WWW::Search

CGI::Wiki::Search::DB

Kwiki

Kwiki::Search

Kwiki::Search::Plucene

KinoSearch

Encode

I18N::Charset

Unicode::Map

Unicode::Map8

Unicode::MapUTF8

WWW::Search::UrbanDictionary

XML::Simple

JSON

WebService::Nestoria::Search

CGI::Kwiki

XML::DOM

WWW::Search::PubMed

Class::Gomor

Net::Pcap

Config

Socket6

Net::Write

Net::IPv4Addr

Math::Base85

Net::IPv6Addr

Geo::GPS::Data::Search

WWW::Search::FirstGov

CGI::Application

XML::SAX

XML::NamespaceSupport

XML::LibXML::Common

XML::LibXML

XML::LibXSLT

XML::Xpath

IO::Extended

WWW::Search::NCBI::PubMed

File::Flock

Class::Generate

File::Searcher

Date::Parse

Mail::Mbox::MessageParser

IO::Capture::Extended

WWW::Search::Monster

Test::Memory::Cycle

Test::Warn

Test::Taint

Test::Inline

URI::ParseSearchString

HTML::SuperForm

Class::Factory

HTML::Template

HTML::DBForm

ExtUtils::Manifest

Devel::Cover

Carp::Assert::More

SWF::Search

WebService::GoogleHack

LWP::Simple

WWW::Search::Ebay

Pod::Index

Net::LDAP::Search

Perldoc::Search

WWW::Arbeitsagentur::Search

XML::Dumper

HTTP::Date

HTML::Pretty

HTML::FormatText

Object::eBay

WWW::Ebay

WWW::CheckSite

WWW::Mechanize

WWW::Mechanized::Cached

WWW::Overture::Keywords

LWP::Cookies::Simple

Time::Duration

Time::Duration::Object

Time::Duration::ja

Time::Duration::Parse

Time::Duration::sv

Time::Duration::Object::Infinite

Time::Concise

WWW::BitTorrent

PDF::API2

LWP::Parallel::UserAgent

WWW::Robot

WWW::RobotRules::Parser

WWW::RobotRules::MySQLCache

WWW::Search::Rambler

WWW::Search::Yandex

WWW::Scraper::ISBN

WWW::Scraper::ISBN::Driver

WWW::Scraper::ISBN::ISBNnu_Driver

WWW::Scraper::ISBN::LOC_Driver

WWW::Scraper::ISBN::Record

Socket

HTTP::Lite

WWW::Fuel::US::Prices

Gas::Prices

XML::RSS

WWW::SherlockSearch

WWW::Sitemap

CGI_Lite

WWW::SimpleRobot

Template::Extract

WWW::Scraper::ISBN::ORA_Driver

WWW::Scraper::ISBN::Yahoo_Driver

WWW::Authenticate

WWW::Yandex::TIC

WWW::Meta::XML::Browser

WWW::Simpy

WWW::B_Rail

WWW::BugMeNot

WWW::RaptureReady

WWW::Gazetteer::HeavensAbove

WWW::CMS

WWW::EmpireTheatres

WWW::OpenSearch

WWW::Wikipedia

WWW::Find

WWW::PkgFind

Class::ErrorHandler

Feed::Find

WWW::Blog::Metadata::Icon

WWW::IstanbulTeknik

WWW::Freshmeat

WWW::Search::Tv::Sweden::TvDotNu

WWW::Dictionary

WWW::Mechanize::FormFiller

WWW::Mechanize::Shell

WWW::Mechanize::Frames

WWW::ImageSpool

WWW::YahooMaps

WWW::Scraper::ISBN::ISBNdb_Driver

WWW::Search::DrugBank

WWW::Search::HGNC

WWW::JASRAC

WWW::NanoRef

WWW::Agent

WWW::Dropload

WWW::Babelfish

WWW::Shorten::Smallr

HTML::ElementTable

WWW::SMS

WWW::Lipsum

WWW::Auth

WWW::Translate::Apertium

WWW::Translate::interNOSTRUM

WWW::YouTube

WWW::Mechanize::Sleepy

WWW::Zorpia::Upload

Bundle::WWW::Scraper::Housing

WWW::LiveDepartureBoards

WWW::Extractor

WWW::Dict::OKDaily

WWW::Dict::TWMOE::Phrase

UNIVERSAL::require

Template::Provider::Encoding

Text::Tags

DateTime

DateTime::TimeZone

DateTime::Locale

DateTime::Format::Mail

DateTime::Format::W3CDTF

DateTime::Format::Strptime

URI::Fetch

Module::Pluggable::Fast

HTML::ResolveLink

MIME::Types

LWP::Authen::Wsse

XML::RSS

XML::RSS::LibXML

XML::Atom

Encode

XML::Atom::SimpleFeed

Term::Encoding

File::HomeDir

YAML::Loader

Test::Base

Encode::Detect

XML::Liberal

XML::RSS::Liberal

HTML::TreeBuilder::XPath

DateTime::Format::Japanese

SVN::Agent

SVN::Access

SVN::Dump

SVN::Pusher

SVN::Simple::Edit

Test::Chimps::Client

SVN::Notify::Mirror

XML::RSS::Parser

SVN::RaWeb::Light

SVN::Log

Plagger

WWW::Lipsum::Chinese

WWW::Live365

WWW::Pipeline

WWW::Scraper::ISBN::TWApexbook_Driver

WWW::Scraper::ISBN::TWBooks_Driver

WWW::Scraper::ISBN::TWEslitebooks_Driver

WWW::Scraper::ISBN::TWKingstone_Driver

WWW::Scraper::ISBN::TWPchome_Driver

WWW::Scraper::ISBN::TWSanmin_Driver

WWW::Scraper::ISBN::TWSrbook_Driver

WWW::Scraper::ISBN::TWYlib_Driver

WWW::RobotRules::DBIC

WWW::Mixi::Scraper

WWW::Resource

WWW::URLToys

WWW::IndexParser

WWW::Restaurant::Menu

WWW::A9Toolbar

WWW::Search::Teoma

WWW::Search::AlltheWeb

WWW::Search::PRWire

WWW::Search::Translator

WWW::Search::YahooNews

WWW::LargeFileFetcher

WWW::CybozuOffice6

WWW::Blog::Metadata::AccountAutoDiscovery

WWW::Blog::Metadata::Microsummary

WWW::MySpaceBot

WWW::Blog::Metadata::Yadis

WWW::PlaceEngine

WWW::AltaRank

WWW::Yandex::CY

WWW::Gazetteer

WWW::Gazetteer::FallingRain

WWW::Mechanize::Timed

WWW::MapBlast

WWW::Search::TheITJobBoard

WWW::Scraper::ISBN::LibUniIt_Driver

Test::WWW::Selenium

WWW::Selenium::Utils

WWW::SMS::IE::aftsms

WWW::HostipInfo

WWW::Orkut::Spider

WWW::Mediawiki::Client

WWW::Mechanize::Plugin::Display

WWW::Domain::Registry::Afilias

WWW::Domain::Registry::VeriSign

WWW::Blog::Identify

WWW::Ofoto

WWW::Baseball::NPB

WWW::Blog::Metadata::MobileLinkDiscovery

WWW::Blog::Metadata::OpenID

WWW::Blog::Metadata::OpenSearch

WWW::Fido

Buffalo::G54

WWW::Search::Jarit

WWW::Dilbert

WWW::Comic

WWW::FleXtel

WWW::VenusEnvy

WWW::Module

WWW::Postini

WWW::Slides

WWW::BookBot

WWW::Mail15

WWW::ConfixxBackup

WWW::TWikiClient

WWW::Facebook::FQL

WWW::MSA::Hadith

WWW::Form

WWW::OpenSVN

WWW::Search::MSN

WWW::Topica

WWW::Promotion

WWW::Bleep

WWW::TWSMS

WWW::CloudCreator

WWW::RobotRules::Memcache

WWW::Search::Feedster

WWW::Wow::RealmStatus

WWW::WebArchive

WWW::StreetMap

WWW::phpBB

WWW::Yahoo::Movies

WWW::Moreshet

WWW::BBSWatch

WWW::Sucksub::Attila

WWW::Sucksub::Divxstation

WWW::Sucksub::Extratitles

WWW::Sucksub::Frigo

WWW::Sucksub::Vostfree

WWW::Mixi

WWW::Facebook::API

WWW::Authen::Simple

WWW::Mechanize::TWiki

WWW::Mechanize::XML

WWW::BF2Player

WWW::BF2S

WWW::GameMonitor

WWW::Hotmail

WWW::Bookmark::Crawler

WWW::Search::AcronymFinder

WWW::Streamripper::WebUI

WWW::2ch

WWW::Monitor

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-Search-0.02.tar.gz: Bundle-Search-0.02/lib/Bundle/Search.pm <==
package Bundle::Search;

use strict;
use warnings;

our $VERSION = '0.02';



1;
__END__


=head1 NAME

Bundle::Search - installs Search modules, related modules, and
                 dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Search'
  
=head1 CONTENTS

IPC::Shareable

Digest::SHA1

SHA

Digest::base

File::Find::Object

Heap

Term::ReadKey

Date::Format

Time::Zone 

Clone

Sub::Uplevel

Test::Simple

Test::Harness

IO::Stringy

DBI::PurePerl

App::Info

Time::Local

File::Which

File::Temp

File::Copy::Reliable

Data::Dumper

File::chdir 

ExtUtils::CBuilder

Module::Build

Test

Scalar::Util

File::Basename::Object

Cache

Cache::Cache

Error

IPC::ShareLite

File::Cache

FreezeThaw

Cache::File

DB_File

File::NFSLock

Storable

Test::Exception

DBI

DBD::Pg

Archive::Zip

Bundle::Compress::Zlib

IO

IO::Zlib

IO::Select::Trap

Carp

XSLoader

Log::Agent

IO::File::Log

IO::File::CompressOnClose

IO::Tokenized

IO::BLOB::Pg

IO::File::Multi

IO::File::String

IO::File::Cached

DBD::AnyData

DBD::CSV

DBD::DBM

DBD::File

DBD::Gofer

DBD::mysql

DBD::NullP

DBD::Proxy

DBD::Sponge

SQL::Statement 

DBD::Template

DBD::TemplateSS

DBD::WMI

DBD::Excel

Bundle::Mysql

Bundle::SQL

AutoLoader

Pod::Simple

Test::Builder

Test::Builder::Tester

File::Spec

Pod::Coverage

Test::Pod 

Test::Pod::Coverage

Search::Glimpse

LWP

URI

HTML::Tagset

HTML::Parser

Search::Circa::Parser

String::Tokenizer

String::Tokeniser

Parse::Tokens

Text::Tokenizer

Search::QueryParser

Getopt::Long

Pragmatic

Time::Piece

Snowball::Norwegian

Bundle::Encode

Bundle::Unicode

Bundle::PlRPC

Carp::Assert

Class::ISA

Class::Data::Inheritable

Class::Contract 

Class::Class

Class::Generate

Class::MethodMaker

Carp::Clan

Text::German

Lingua::Stem

Lingua::Stem::Snowball::Da

Lingua::Stem::Fr

Lingua::Stem::It

Lingua::Stem::Ru

Lingua::PT::Stemmer

Tie::Array::Sorted

Memoize

List::Util

Class::Virtual

Class::Accessor

Class::Accessor::Fast

Bit::Vector

Bit::Vector::Minimal

Lucene

AnnoCPAN::Perldoc

AnnoCPAN::Perldoc::SyncDB

Params::Util

CSS::Tiny

Hook::LexWrap

Config::Tiny

Class::Inspector

File::Remove

Test::SubCalls

Test::ClassAPI

Test::Object

PPI 

PPI::HTML

Uri::QueryParam

Time::HiRes

Pod::POM

Pod::POM::View::HTML

Module::CoreList

List::MoreUtils

HTTP::Daemon

Encode::Guess

Config

Alien::GvaScript

Pod::POM::Web

Plucene

Search::FreeText

BerkeleyDB

Search::Indexer

Search::Estraier

Search::Equidistance

Search::Odeum

Class::ParmList

Class::NamedParms

Tie::FileLRUCache

Tie::DB_File::SplitHash

Search::InvertedIndex

Search::InvertedIndex::DB::Pg

Text::Aspell

Search::Tools

Search::Namazu

Text::Unidecode

Search::ContextGraph

Path::Class

List::Uniq

Class::Accessor::Chained

Set::Scalar

CDB_File

Text::Soundex

MealMaster

Search::Mousse

Search::VectorSpace

PerlBench::Stats

MARC

MARC::Record

YAML

Search::Lemur

Search::Binary

Want

Set::Array

Search::InvertedIndex::Simple

Search::InvertedIndex::Simple::BerkeleyDB

Search::FreeText

Date::Manip

CGI

HTML::Tree

HTML::TreeBuilder

IO::Capture::ErrorMessages

Pod::Usage

URI::Escape::XS

User

Test::File

Test::Pod

Email::Address

Email::Simple

Return::Value

Email::Send

WWW::Search

CGI::Wiki::Search::DB

Kwiki

Kwiki::Search

Kwiki::Search::Plucene

KinoSearch

Encode

I18N::Charset

Unicode::Map

Unicode::Map8

Unicode::MapUTF8

WWW::Search::UrbanDictionary

XML::Simple

JSON

WebService::Nestoria::Search

CGI::Kwiki

XML::DOM

WWW::Search::PubMed

Class::Gomor

Net::Pcap

Config

Socket6

Net::Write

Net::IPv4Addr

Math::Base85

Net::IPv6Addr

Geo::GPS::Data::Search

WWW::Search::FirstGov

CGI::Application

XML::SAX

XML::NamespaceSupport

XML::LibXML::Common

XML::LibXML

XML::LibXSLT

XML::XPath

IO::Extended

WWW::Search::NCBI::PubMed

File::Flock

Class::Generate

File::Searcher

Date::Parse

Mail::Mbox::MessageParser

IO::Capture::Extended

WWW::Search::Monster

Test::Memory::Cycle

Test::Warn

Test::Taint

Test::Inline

URI::ParseSearchString

HTML::SuperForm

Class::Factory

HTML::Template

HTML::DBForm

ExtUtils::Manifest

Devel::Cover

Carp::Assert::More

SWF::Search

WebService::GoogleHack

LWP::Simple

WWW::Search::Ebay

Pod::Index

Net::LDAP::Search

Perldoc::Search

WWW::Arbeitsagentur::Search

XML::Dumper

HTTP::Date

HTML::PrettyPrinter

HTML::FormatText

Object::eBay

WWW::Ebay

WWW::CheckSite

WWW::Mechanize

WWW::Mechanize::Cached

WWW::Overture::Keywords

LWP::Simple::Cookies

Time::Duration

Time::Duration::Object

Time::Duration::ja

Time::Duration::Parse

Time::Duration::sv

Time::Duration::Object::Infinite

Time::Concise

WWW::BitTorrent

PDF::API2

LWP::Parallel::UserAgent

WWW::Robot

WWW::RobotRules::Parser

WWW::RobotRules::MySQLCache

WWW::Search::Rambler

WWW::Search::Yandex

WWW::Scraper::ISBN

WWW::Scraper::ISBN::Driver

WWW::Scraper::ISBN::ISBNnu_Driver

WWW::Scraper::ISBN::LOC_Driver

WWW::Scraper::ISBN::Record

Socket

HTTP::Lite

WWW::Fuel::US::Prices

Gas::Prices

XML::RSS

WWW::SherlockSearch

WWW::Sitemap

CGI_Lite

WWW::SimpleRobot

Template::Extract

WWW::Scraper::ISBN::ORA_Driver

WWW::Scraper::ISBN::Yahoo_Driver

WWW::Authenticate

WWW::Yandex::TIC

WWW::Meta::XML::Browser

WWW::Simpy

WWW::B_Rail

WWW::BugMeNot

WWW::RaptureReady

WWW::Gazetteer::HeavensAbove

WWW::CMS

WWW::EmpireTheatres

WWW::OpenSearch

WWW::Wikipedia

WWW::Find

WWW::PkgFind

Class::ErrorHandler

Feed::Find

WWW::Blog::Metadata::Icon

WWW::IstanbulTeknik

WWW::Freshmeat

WWW::Search::Tv::Sweden::TvDotNu

WWW::Dictionary

WWW::Mechanize::FormFiller

WWW::Mechanize::Shell

WWW::Mechanize::Frames

WWW::ImageSpool

WWW::YahooMaps

WWW::Scraper::ISBN::ISBNdb_Driver

WWW::Search::DrugBank

WWW::Search::HGNC

WWW::JASRAC

WWW::NanoRef

WWW::Agent

WWW::Dropload

WWW::Babelfish

WWW::Shorten::Smallr

HTML::ElementTable

WWW::SMS

WWW::Lipsum

WWW::Auth

WWW::Translate::Apertium

WWW::Translate::interNOSTRUM

WWW::YouTube

WWW::Mechanize::Sleepy

WWW::Zorpia::Upload

Bundle::WWW::Scraper::Housing

WWW::LiveDepartureBoards

WWW::Extractor

WWW::Dict::OKDaily

WWW::Dict::TWMOE::Phrase

UNIVERSAL::require

Template::Provider::Encoding

Text::Tags

DateTime

DateTime::TimeZone

DateTime::Locale

DateTime::Format::Mail

DateTime::Format::W3CDTF

DateTime::Format::Strptime

URI::Fetch

Module::Pluggable::Fast

HTML::ResolveLink

MIME::Types

LWP::Authen::Wsse

XML::RSS

XML::RSS::LibXML

XML::Atom

Encode

XML::Atom::SimpleFeed

Term::Encoding

File::HomeDir

YAML::Loader

Test::Base

Encode::Detect

XML::Liberal

XML::RSS::Liberal

HTML::TreeBuilder::XPath

DateTime::Format::Japanese

SVN::Agent

SVN::Access

SVN::Dump

SVN::Pusher

SVN::Simple::Edit

Test::Chimps::Client

SVN::Notify::Mirror

XML::RSS::Parser

SVN::RaWeb::Light

SVN::Log

Plagger

WWW::Lipsum::Chinese

WWW::Live365

WWW::Pipeline

WWW::Scraper::ISBN::TWApexbook_Driver

WWW::Scraper::ISBN::TWBooks_Driver

WWW::Scraper::ISBN::TWEslitebooks_Driver

WWW::Scraper::ISBN::TWKingstone_Driver

WWW::Scraper::ISBN::TWPchome_Driver

WWW::Scraper::ISBN::TWSanmin_Driver

WWW::Scraper::ISBN::TWSrbook_Driver

WWW::Scraper::ISBN::TWYlib_Driver

WWW::RobotRules::DBIC

WWW::Mixi::Scraper

WWW::Resource

WWW::URLToys

WWW::IndexParser

WWW::Restaurant::Menu

WWW::A9Toolbar

WWW::Search::Teoma

WWW::Search::AlltheWeb

WWW::Search::PRWire

WWW::Search::Translator

WWW::Search::YahooNews

WWW::LargeFileFetcher

WWW::CybozuOffice6

WWW::Blog::Metadata::AccountAutoDiscovery

WWW::Blog::Metadata::Microsummary

WWW::MySpaceBot

WWW::Blog::Metadata::Yadis

WWW::PlaceEngine

WWW::AltaRank

WWW::Yandex::CY

WWW::Gazetteer

WWW::Gazetteer::FallingRain

WWW::Mechanize::Timed

WWW::MapBlast

WWW::Search::TheITJobBoard

WWW::Scraper::ISBN::LibUniIt_Driver

Test::WWW::Selenium

WWW::Selenium::Utils

WWW::SMS::IE::aftsms

WWW::HostipInfo

WWW::Orkut::Spider

WWW::Mediawiki::Client

WWW::Mechanize::Plugin::Display

WWW::Domain::Registry::Afilias

WWW::Domain::Registry::VeriSign

WWW::Blog::Identify

WWW::Ofoto

WWW::Baseball::NPB

WWW::Blog::Metadata::MobileLinkDiscovery

WWW::Blog::Metadata::OpenID

WWW::Blog::Metadata::OpenSearch

WWW::Fido

Buffalo::G54

WWW::Search::Jarit

WWW::Dilbert

WWW::Comic

WWW::FleXtel

WWW::VenusEnvy

WWW::Module

WWW::Postini

WWW::Slides

WWW::BookBot

WWW::Mail15

WWW::ConfixxBackup

WWW::TWikiClient

WWW::Facebook::FQL

WWW::MSA::Hadith

WWW::Form

WWW::OpenSVN

WWW::Search::MSN

WWW::Topica

WWW::Promotion

WWW::Bleep

WWW::TWSMS

WWW::CloudCreator

WWW::RobotRules::Memcache

WWW::Search::Feedster

WWW::Wow::RealmStatus

WWW::WebArchive

WWW::StreetMap

WWW::phpBB

WWW::Yahoo::Movies

WWW::Moreshet

WWW::BBSWatch

WWW::Sucksub::Attila

WWW::Sucksub::Divxstation

WWW::Sucksub::Extratitles

WWW::Sucksub::Frigo

WWW::Sucksub::Vostfree

WWW::Mixi

WWW::Facebook::API

WWW::Authen::Simple

WWW::Mechanize::TWiki

WWW::Mechanize::XML

WWW::BF2Player

WWW::BF2S

WWW::GameMonitor

WWW::Hotmail

WWW::Bookmark::Crawler

WWW::Search::AcronymFinder

WWW::Streamripper::WebUI

WWW::2ch

WWW::Monitor

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
